hepstats.utils package
======================

.. automodule:: hepstats.utils
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   hepstats.utils.fit
